@@ -1,24 +1,24 @@
-package Number::Tolerant::Type::or_less;
-use base qw(Number::Tolerant::Type);
-
 use strict;
 use warnings;
 
-our $VERSION = '1.550';
+package Number::Tolerant::Type::or_less;
+use base qw(Number::Tolerant::Type);
+
+our $VERSION = '1.600';
 
 sub construct { shift; { value => $_[0], max => $_[0] } }
 
 sub parse {
-  my $self = shift;
+  my ($self, $string, $factory) = @_;
+
   my $number = $self->number_re;
   my $X = $self->variable_re;
 
-  return Number::Tolerant::tolerance("$1", 'or_less')
-    if ($_[0] =~ m!\A$X?<=\s*($number)\z!);
-  return Number::Tolerant::tolerance("$1", 'or_less')
-    if ($_[0] =~ m!\A($number)\s*>=$X\z!);
-  return Number::Tolerant::tolerance("$1", 'or_less')
-    if ($_[0] =~ m!\A($number)\s+or\s+less\z!);
+  return $factory->new("$1", 'or_less') if $string =~ m!\A$X?<=\s*($number)\z!;
+  return $factory->new("$1", 'or_less') if $string =~ m!\A($number)\s*>=$X\z!;
+  return $factory->new("$1", 'or_less')
+    if $string =~ m!\A($number)\s+or\s+less\z!;
+
   return;
 }
 
